pub struct AgentAccessPolicy {
pub allowed_scopes: Vec<String>,
pub allow_unspecified_scope: bool,
pub max_limit: usize,
pub max_context_bytes: usize,
pub max_runtime_ms: u64,
pub allow_remote_clients: bool,
}Expand description
Local access policy applied before agent protocol requests reach services.
Fields
allowed_scopes: Vec<String>allow_unspecified_scope: boolmax_limit: usizemax_context_bytes: usizemax_runtime_ms: u64allow_remote_clients: boolImplementations
Sourceimpl AgentAccessPolicy
impl AgentAccessPolicy
pub const DEFAULT_MAX_LIMIT: usize = 10
pub const DEFAULT_MAX_CONTEXT_BYTES: usize = 65_536
Sourcepub fn new(
allowed_scopes: Vec<String>,
allow_unspecified_scope: bool,
max_limit: usize,
max_context_bytes: usize,
max_runtime_ms: u64,
allow_remote_clients: bool,
) -> Result<Self, AgentPolicyError>
pub fn new( allowed_scopes: Vec<String>, allow_unspecified_scope: bool, max_limit: usize, max_context_bytes: usize, max_runtime_ms: u64, allow_remote_clients: bool, ) -> Result<Self, AgentPolicyError>
Creates a validated access policy for agent protocol adapters.
Sourcepub fn summary(&self) -> AgentAccessPolicySummary
pub fn summary(&self) -> AgentAccessPolicySummary
Summarizes policy without exposing scope names or secrets.