pub struct AgentRequestContext {
pub request: RequestContext,
pub runtime_identity: RuntimeIdentity,
pub policy_id: String,
}Expand description
Unified API context plus agent protocol identity and policy provenance.
Fields
request: RequestContextruntime_identity: RuntimeIdentitypolicy_id: StringTrait Implementations
Sourceimpl Clone for AgentRequestContext
impl Clone for AgentRequestContext
Sourcefn clone(&self) -> AgentRequestContext
fn clone(&self) -> AgentRequestContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentRequestContext
impl Debug for AgentRequestContext
Sourceimpl<'de> Deserialize<'de> for AgentRequestContext
impl<'de> Deserialize<'de> for AgentRequestContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AgentRequestContext
impl PartialEq for AgentRequestContext
Sourcefn eq(&self, other: &AgentRequestContext) -> bool
fn eq(&self, other: &AgentRequestContext) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentRequestContext
impl Serialize for AgentRequestContext
impl Eq for AgentRequestContext
impl StructuralPartialEq for AgentRequestContext