pub struct CodeRepositoryIndexStartResponse {
pub metadata: ApiMetadata,
pub scope: CodeRepositoryScopeMetadata,
pub summary: Option<CodeIndexSummary>,
pub status: CodeRepositoryStatus,
pub task: Option<CodeIndexTaskRecord>,
pub checkpoint: Option<CodeIndexCheckpoint>,
}Expand description
Code repository index start response for queued or no-op index requests.
Fields
metadata: ApiMetadatascope: CodeRepositoryScopeMetadatasummary: Option<CodeIndexSummary>status: CodeRepositoryStatustask: Option<CodeIndexTaskRecord>checkpoint: Option<CodeIndexCheckpoint>Trait Implementations
Sourceimpl Clone for CodeRepositoryIndexStartResponse
impl Clone for CodeRepositoryIndexStartResponse
Sourcefn clone(&self) -> CodeRepositoryIndexStartResponse
fn clone(&self) -> CodeRepositoryIndexStartResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CodeRepositoryIndexStartResponse
impl<'de> Deserialize<'de> for CodeRepositoryIndexStartResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CodeRepositoryIndexStartResponse
impl PartialEq for CodeRepositoryIndexStartResponse
Sourcefn eq(&self, other: &CodeRepositoryIndexStartResponse) -> bool
fn eq(&self, other: &CodeRepositoryIndexStartResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CodeRepositoryIndexStartResponse
impl StructuralPartialEq for CodeRepositoryIndexStartResponse