pub struct CodeRepositoryScopeMetadata {
pub scope_id: String,
pub repository_id: String,
pub alias: String,
pub requested_ref: String,
pub resolved_commit_sha: String,
pub tree_hash: String,
pub path_filters: Vec<String>,
pub language_filters: Vec<String>,
pub index_versions: Vec<String>,
pub stale: bool,
}Expand description
Code repository scope and index metadata attached to code responses.
Fields
scope_id: Stringrepository_id: Stringalias: Stringrequested_ref: Stringresolved_commit_sha: Stringtree_hash: Stringpath_filters: Vec<String>language_filters: Vec<String>index_versions: Vec<String>stale: boolImplementations
Sourceimpl CodeRepositoryScopeMetadata
impl CodeRepositoryScopeMetadata
Sourcepub fn from_status(
status: &CodeRepositoryStatus,
selector: &CodeRepositorySelector,
requested_ref: impl Into<String>,
) -> Self
pub fn from_status( status: &CodeRepositoryStatus, selector: &CodeRepositorySelector, requested_ref: impl Into<String>, ) -> Self
Builds stable scope metadata from the selected repository snapshot.
Sourcepub fn from_index_task(
task: &CodeIndexTaskRecord,
requested_ref: impl Into<String>,
) -> Self
pub fn from_index_task( task: &CodeIndexTaskRecord, requested_ref: impl Into<String>, ) -> Self
Builds scope metadata for a queued or running index task.