pub struct GraphInspectionRequest {
pub source_scope: Option<String>,
}Expand description
Graph inspection request with optional scope filtering reserved for adapters.
Fields
source_scope: Option<String>Trait Implementations
Sourceimpl Clone for GraphInspectionRequest
impl Clone for GraphInspectionRequest
Sourcefn clone(&self) -> GraphInspectionRequest
fn clone(&self) -> GraphInspectionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphInspectionRequest
impl Debug for GraphInspectionRequest
Sourceimpl<'de> Deserialize<'de> for GraphInspectionRequest
impl<'de> Deserialize<'de> for GraphInspectionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GraphInspectionRequest
impl PartialEq for GraphInspectionRequest
Sourcefn eq(&self, other: &GraphInspectionRequest) -> bool
fn eq(&self, other: &GraphInspectionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GraphInspectionRequest
impl Serialize for GraphInspectionRequest
impl Eq for GraphInspectionRequest
impl StructuralPartialEq for GraphInspectionRequest