pub struct ProjectStatusResponse {
pub project_name: String,
pub metadata: ApiMetadata,
pub runtime: RuntimeStatus,
}Expand description
Minimal project status response exposed through the unified API layer.
Fields
project_name: Stringmetadata: ApiMetadataruntime: RuntimeStatusTrait Implementations
Sourceimpl Clone for ProjectStatusResponse
impl Clone for ProjectStatusResponse
Sourcefn clone(&self) -> ProjectStatusResponse
fn clone(&self) -> ProjectStatusResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectStatusResponse
impl Debug for ProjectStatusResponse
Sourceimpl<'de> Deserialize<'de> for ProjectStatusResponse
impl<'de> Deserialize<'de> for ProjectStatusResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProjectStatusResponse
Sourceimpl PartialEq for ProjectStatusResponse
impl PartialEq for ProjectStatusResponse
Sourcefn eq(&self, other: &ProjectStatusResponse) -> bool
fn eq(&self, other: &ProjectStatusResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProjectStatusResponse
impl Serialize for ProjectStatusResponse
impl StructuralPartialEq for ProjectStatusResponse