pub struct RuntimeStatus {Show 50 fields
pub config_dir: String,
pub data_dir: String,
pub state_dir: String,
pub cache_dir: String,
pub log_dir: String,
pub temp_dir: String,
pub runtime_dir: String,
pub service_dir: String,
pub http_bind: String,
pub http_request_timeout_ms: u64,
pub http_graceful_shutdown_timeout_ms: u64,
pub http_max_request_body_bytes: u64,
pub http_proxy_configured: bool,
pub http_no_proxy_rules: usize,
pub http_ssl_verify: bool,
pub qos_max_connections: usize,
pub qos_max_in_flight_requests: usize,
pub qos_max_queue_depth: usize,
pub worker_embedding_endpoint_configured: bool,
pub worker_ocr_endpoint_configured: bool,
pub worker_vision_endpoint_configured: bool,
pub worker_extractor_endpoint_configured: bool,
pub worker_max_in_flight: usize,
pub silent_updates_enabled: bool,
pub file_index_enabled: bool,
pub file_index_root_count: usize,
pub file_index_max_depth: usize,
pub file_index_max_file_bytes: u64,
pub file_index_scan_interval_ms: u64,
pub file_index_scan_timeout_ms: u64,
pub file_index_max_files_per_root: usize,
pub file_query_timeout_ms: u64,
pub semantic_backend_mode: String,
pub vector_backend_mode: String,
pub rerank_backend_mode: String,
pub rerank_model: Option<String>,
pub rerank_candidate_multiplier: usize,
pub rerank_max_candidates: usize,
pub rerank_timeout_ms: u64,
pub embedding_provider: Option<String>,
pub embedding_base_url: Option<String>,
pub embedding_api_key_configured: bool,
pub text_embedding_model: String,
pub image_embedding_model: String,
pub embedding_dimension: u32,
pub embedding_batch_size: Option<usize>,
pub embedding_timeout_ms: Option<u64>,
pub embedding_max_concurrency: Option<usize>,
pub model_profiles: ModelProfileRuntimeSummary,
pub telemetry: TelemetryStatus,
}Expand description
Resolved runtime paths and network budgets exposed for diagnostics.
Fields
config_dir: Stringdata_dir: Stringstate_dir: Stringcache_dir: Stringlog_dir: Stringtemp_dir: Stringruntime_dir: Stringservice_dir: Stringhttp_bind: Stringhttp_request_timeout_ms: u64http_graceful_shutdown_timeout_ms: u64http_max_request_body_bytes: u64http_proxy_configured: boolhttp_no_proxy_rules: usizehttp_ssl_verify: boolqos_max_connections: usizeqos_max_in_flight_requests: usizeqos_max_queue_depth: usizeworker_embedding_endpoint_configured: boolworker_ocr_endpoint_configured: boolworker_vision_endpoint_configured: boolworker_extractor_endpoint_configured: boolworker_max_in_flight: usizesilent_updates_enabled: boolfile_index_enabled: boolfile_index_root_count: usizefile_index_max_depth: usizefile_index_max_file_bytes: u64file_index_scan_interval_ms: u64file_index_scan_timeout_ms: u64file_index_max_files_per_root: usizefile_query_timeout_ms: u64semantic_backend_mode: Stringvector_backend_mode: Stringrerank_backend_mode: Stringrerank_model: Option<String>rerank_candidate_multiplier: usizererank_max_candidates: usizererank_timeout_ms: u64embedding_provider: Option<String>embedding_base_url: Option<String>embedding_api_key_configured: booltext_embedding_model: Stringimage_embedding_model: Stringembedding_dimension: u32embedding_batch_size: Option<usize>embedding_timeout_ms: Option<u64>embedding_max_concurrency: Option<usize>model_profiles: ModelProfileRuntimeSummarytelemetry: TelemetryStatusTrait Implementations
Sourceimpl Clone for RuntimeStatus
impl Clone for RuntimeStatus
Sourcefn clone(&self) -> RuntimeStatus
fn clone(&self) -> RuntimeStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeStatus
impl Debug for RuntimeStatus
Sourceimpl<'de> Deserialize<'de> for RuntimeStatus
impl<'de> Deserialize<'de> for RuntimeStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RuntimeStatus
impl PartialEq for RuntimeStatus
Sourcefn eq(&self, other: &RuntimeStatus) -> bool
fn eq(&self, other: &RuntimeStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RuntimeStatus
impl Serialize for RuntimeStatus
impl Eq for RuntimeStatus
impl StructuralPartialEq for RuntimeStatus