pub struct CodeIndexProgressSummary {
pub git_file_count: usize,
pub blob_read_count: usize,
pub parsed_file_count: usize,
pub sqlite_write_count: usize,
pub skipped_file_count: usize,
pub degraded_file_count: usize,
pub batch_count: usize,
pub checkpoint_file_count: usize,
pub resource_budget: CodeIndexResourceBudget,
}Expand description
Coarse phase timing and counts reported by repository indexing.
Fields
git_file_count: usizeblob_read_count: usizeparsed_file_count: usizesqlite_write_count: usizeskipped_file_count: usizedegraded_file_count: usizebatch_count: usizecheckpoint_file_count: usizeresource_budget: CodeIndexResourceBudgetTrait Implementations
Sourceimpl Clone for CodeIndexProgressSummary
impl Clone for CodeIndexProgressSummary
Sourcefn clone(&self) -> CodeIndexProgressSummary
fn clone(&self) -> CodeIndexProgressSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeIndexProgressSummary
impl Debug for CodeIndexProgressSummary
Sourceimpl Default for CodeIndexProgressSummary
impl Default for CodeIndexProgressSummary
Sourcefn default() -> CodeIndexProgressSummary
fn default() -> CodeIndexProgressSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CodeIndexProgressSummary
impl<'de> Deserialize<'de> for CodeIndexProgressSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CodeIndexProgressSummary
impl PartialEq for CodeIndexProgressSummary
Sourcefn eq(&self, other: &CodeIndexProgressSummary) -> bool
fn eq(&self, other: &CodeIndexProgressSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CodeIndexProgressSummary
impl Serialize for CodeIndexProgressSummary
impl Eq for CodeIndexProgressSummary
impl StructuralPartialEq for CodeIndexProgressSummary