pub struct CodeIndexTaskRecord {Show 22 fields
pub task_id: String,
pub repository_id: String,
pub alias: String,
pub ref_selector: String,
pub resolved_commit_sha: String,
pub tree_hash: String,
pub source_scope: String,
pub path_filters: Vec<String>,
pub language_filters: Vec<String>,
pub mode: CodeIndexMode,
pub state: CodeIndexTaskState,
pub lease_owner: Option<String>,
pub lease_expires_at_ms: Option<u64>,
pub attempt_count: u32,
pub next_retry_at_ms: u64,
pub input_fingerprint: String,
pub resource_budget: CodeIndexResourceBudget,
pub payload_json: String,
pub last_error_kind: Option<String>,
pub last_error_message: Option<String>,
pub created_at_ms: u64,
pub updated_at_ms: u64,
}Expand description
Durable background task for one code repository index request.
Fields
task_id: Stringrepository_id: Stringalias: Stringref_selector: Stringresolved_commit_sha: Stringtree_hash: Stringsource_scope: Stringpath_filters: Vec<String>language_filters: Vec<String>mode: CodeIndexModestate: CodeIndexTaskStatelease_owner: Option<String>lease_expires_at_ms: Option<u64>attempt_count: u32next_retry_at_ms: u64input_fingerprint: Stringresource_budget: CodeIndexResourceBudgetpayload_json: Stringlast_error_kind: Option<String>last_error_message: Option<String>created_at_ms: u64updated_at_ms: u64Trait Implementations
Sourceimpl Clone for CodeIndexTaskRecord
impl Clone for CodeIndexTaskRecord
Sourcefn clone(&self) -> CodeIndexTaskRecord
fn clone(&self) -> CodeIndexTaskRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeIndexTaskRecord
impl Debug for CodeIndexTaskRecord
Sourceimpl<'de> Deserialize<'de> for CodeIndexTaskRecord
impl<'de> Deserialize<'de> for CodeIndexTaskRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CodeIndexTaskRecord
Sourceimpl PartialEq for CodeIndexTaskRecord
impl PartialEq for CodeIndexTaskRecord
Sourcefn eq(&self, other: &CodeIndexTaskRecord) -> bool
fn eq(&self, other: &CodeIndexTaskRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CodeIndexTaskRecord
impl Serialize for CodeIndexTaskRecord
impl StructuralPartialEq for CodeIndexTaskRecord