pub struct CodeRepositoryExcludedPath {
pub path: String,
pub reason: String,
}Expand description
Path excluded from indexing by preset, ignore file, or request scope.
Fields
path: Stringreason: StringTrait Implementations
Sourceimpl Clone for CodeRepositoryExcludedPath
impl Clone for CodeRepositoryExcludedPath
Sourcefn clone(&self) -> CodeRepositoryExcludedPath
fn clone(&self) -> CodeRepositoryExcludedPath
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeRepositoryExcludedPath
impl Debug for CodeRepositoryExcludedPath
Sourceimpl<'de> Deserialize<'de> for CodeRepositoryExcludedPath
impl<'de> Deserialize<'de> for CodeRepositoryExcludedPath
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CodeRepositoryExcludedPath
impl PartialEq for CodeRepositoryExcludedPath
Sourcefn eq(&self, other: &CodeRepositoryExcludedPath) -> bool
fn eq(&self, other: &CodeRepositoryExcludedPath) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CodeRepositoryExcludedPath
impl StructuralPartialEq for CodeRepositoryExcludedPath