pub struct CodeRetrievalHit {Show 23 fields
pub repository_id: String,
pub scope_id: String,
pub resolved_commit_sha: String,
pub tree_hash: String,
pub path: String,
pub language_id: String,
pub byte_range: RepositoryCodeRange,
pub line_range: RepositoryCodeRange,
pub symbol_snapshot_id: Option<String>,
pub canonical_symbol_id: Option<String>,
pub file_id: Option<String>,
pub retrieval_layers: Vec<CodeRetrievalLayer>,
pub index_versions: Vec<String>,
pub stale: bool,
pub staleness_hint: Option<StalenessHint>,
pub degraded_reason: Option<String>,
pub edge_kind: Option<String>,
pub edge_resolution_state: Option<String>,
pub edge_target_hint: Option<String>,
pub edge_confidence_basis_points: Option<u16>,
pub edge_confidence_tier: Option<String>,
pub score: f64,
pub excerpt: String,
}Expand description
Code retrieval hit with source location, layers, and freshness metadata.
Fields
repository_id: Stringscope_id: Stringresolved_commit_sha: Stringtree_hash: Stringpath: Stringlanguage_id: Stringbyte_range: RepositoryCodeRangeline_range: RepositoryCodeRangesymbol_snapshot_id: Option<String>canonical_symbol_id: Option<String>file_id: Option<String>retrieval_layers: Vec<CodeRetrievalLayer>index_versions: Vec<String>stale: boolstaleness_hint: Option<StalenessHint>degraded_reason: Option<String>edge_kind: Option<String>edge_resolution_state: Option<String>edge_target_hint: Option<String>edge_confidence_basis_points: Option<u16>edge_confidence_tier: Option<String>score: f64excerpt: StringTrait Implementations
Sourceimpl Clone for CodeRetrievalHit
impl Clone for CodeRetrievalHit
Sourcefn clone(&self) -> CodeRetrievalHit
fn clone(&self) -> CodeRetrievalHit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeRetrievalHit
impl Debug for CodeRetrievalHit
Sourceimpl<'de> Deserialize<'de> for CodeRetrievalHit
impl<'de> Deserialize<'de> for CodeRetrievalHit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CodeRetrievalHit
impl PartialEq for CodeRetrievalHit
Sourcefn eq(&self, other: &CodeRetrievalHit) -> bool
fn eq(&self, other: &CodeRetrievalHit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CodeRetrievalHit
impl Serialize for CodeRetrievalHit
impl StructuralPartialEq for CodeRetrievalHit