pub struct CodeRouteRecord {
pub repository_id: String,
pub source_scope: String,
pub route_id: String,
pub file_id: String,
pub path: String,
pub language_id: String,
pub url: String,
pub http_method: String,
pub handler_name: String,
pub handler_symbol_snapshot_id: Option<String>,
pub framework: String,
pub line_range: RepositoryCodeRange,
}Expand description
Web framework route mapping extracted from source code.
Fields
repository_id: Stringsource_scope: Stringroute_id: Stringfile_id: Stringpath: Stringlanguage_id: Stringurl: Stringhttp_method: StringLowercase HTTP verb, or any when a framework route accepts all methods.
handler_name: Stringhandler_symbol_snapshot_id: Option<String>framework: Stringline_range: RepositoryCodeRangeTrait Implementations
Sourceimpl Clone for CodeRouteRecord
impl Clone for CodeRouteRecord
Sourcefn clone(&self) -> CodeRouteRecord
fn clone(&self) -> CodeRouteRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeRouteRecord
impl Debug for CodeRouteRecord
Sourceimpl<'de> Deserialize<'de> for CodeRouteRecord
impl<'de> Deserialize<'de> for CodeRouteRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CodeRouteRecord
Sourceimpl PartialEq for CodeRouteRecord
impl PartialEq for CodeRouteRecord
Sourcefn eq(&self, other: &CodeRouteRecord) -> bool
fn eq(&self, other: &CodeRouteRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CodeRouteRecord
impl Serialize for CodeRouteRecord
impl StructuralPartialEq for CodeRouteRecord