pub struct ContextGraphFact {
pub fact_id: String,
pub kind: ContextGraphFactKind,
pub subject: String,
pub predicate: String,
pub object: Option<String>,
pub evidence_ids: Vec<String>,
pub confidence: ConfidenceScore,
pub status: FactStatus,
pub version_range: GraphVersionRange,
}Expand description
Structured relation, claim, or event that supports a retrieval hit.
Fields
fact_id: Stringkind: ContextGraphFactKindsubject: Stringpredicate: Stringobject: Option<String>evidence_ids: Vec<String>confidence: ConfidenceScorestatus: FactStatusversion_range: GraphVersionRangeTrait Implementations
Sourceimpl Clone for ContextGraphFact
impl Clone for ContextGraphFact
Sourcefn clone(&self) -> ContextGraphFact
fn clone(&self) -> ContextGraphFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContextGraphFact
impl Debug for ContextGraphFact
Sourceimpl<'de> Deserialize<'de> for ContextGraphFact
impl<'de> Deserialize<'de> for ContextGraphFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ContextGraphFact
impl PartialEq for ContextGraphFact
Sourcefn eq(&self, other: &ContextGraphFact) -> bool
fn eq(&self, other: &ContextGraphFact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ContextGraphFact
impl Serialize for ContextGraphFact
impl Eq for ContextGraphFact
impl StructuralPartialEq for ContextGraphFact