pub struct ContextGraphPathEdge {
pub fact_id: String,
pub kind: ContextGraphFactKind,
pub from: String,
pub predicate: String,
pub to: Option<String>,
pub evidence_ids: Vec<String>,
pub confidence: ConfidenceScore,
pub status: FactStatus,
pub version_range: GraphVersionRange,
}Expand description
One edge in a graph path returned through the context pack.
Fields
fact_id: Stringkind: ContextGraphFactKindfrom: Stringpredicate: Stringto: Option<String>evidence_ids: Vec<String>confidence: ConfidenceScorestatus: FactStatusversion_range: GraphVersionRangeTrait Implementations
Sourceimpl Clone for ContextGraphPathEdge
impl Clone for ContextGraphPathEdge
Sourcefn clone(&self) -> ContextGraphPathEdge
fn clone(&self) -> ContextGraphPathEdge
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContextGraphPathEdge
impl Debug for ContextGraphPathEdge
Sourceimpl<'de> Deserialize<'de> for ContextGraphPathEdge
impl<'de> Deserialize<'de> for ContextGraphPathEdge
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContextGraphPathEdge
Sourceimpl PartialEq for ContextGraphPathEdge
impl PartialEq for ContextGraphPathEdge
Sourcefn eq(&self, other: &ContextGraphPathEdge) -> bool
fn eq(&self, other: &ContextGraphPathEdge) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ContextGraphPathEdge
impl Serialize for ContextGraphPathEdge
impl StructuralPartialEq for ContextGraphPathEdge