pub struct IndexStatus {
pub kind: IndexKind,
pub index_version: u64,
pub indexed_graph_version: GraphVersion,
pub state: IndexState,
pub last_error: Option<String>,
}Expand description
Versioned status for a derived index.
Fields
kind: IndexKindindex_version: u64indexed_graph_version: GraphVersionstate: IndexStatelast_error: Option<String>Implementations
Sourceimpl IndexStatus
impl IndexStatus
Sourcepub const fn empty(kind: IndexKind) -> Self
pub const fn empty(kind: IndexKind) -> Self
Creates the initial stale status for an empty derived index.
Sourcepub fn is_stale_for(&self, graph_version: GraphVersion) -> bool
pub fn is_stale_for(&self, graph_version: GraphVersion) -> bool
Returns whether this index is behind the supplied graph version.