pub struct OntologyIdentity {
pub source_scope: SourceScope,
pub domain_id: String,
pub entity_id: String,
pub entity_kind: OntologyEntityKind,
}Expand description
Immutable ontology identity independent of a display label.
Fields
source_scope: SourceScopedomain_id: Stringentity_id: Stringentity_kind: OntologyEntityKindImplementations
Sourceimpl OntologyIdentity
impl OntologyIdentity
Sourcepub fn new(
source_scope: SourceScope,
domain_id: impl Into<String>,
entity_id: impl Into<String>,
entity_kind: OntologyEntityKind,
) -> Result<Self, DomainError>
pub fn new( source_scope: SourceScope, domain_id: impl Into<String>, entity_id: impl Into<String>, entity_kind: OntologyEntityKind, ) -> Result<Self, DomainError>
Validates the scoped identity used to create stable typed entity ids.
Sourcepub fn stable_entity_id(&self) -> String
pub fn stable_entity_id(&self) -> String
Returns a deterministic id that does not depend on the display name.