pub struct SoftwareFile {
pub software_file_id: String,
pub repository_id: String,
pub source_scope: String,
pub path: String,
pub language_id: String,
pub file_role: String,
pub parse_status: String,
pub created_graph_version: GraphVersion,
}Expand description
Projected repository file node for the software global model.
Fields
software_file_id: Stringrepository_id: Stringsource_scope: Stringpath: Stringlanguage_id: Stringfile_role: Stringparse_status: Stringcreated_graph_version: GraphVersionImplementations
Sourceimpl SoftwareFile
impl SoftwareFile
Sourcepub fn new(input: SoftwareFileInput) -> Result<Self, DomainError>
pub fn new(input: SoftwareFileInput) -> Result<Self, DomainError>
Creates a stable file node identity for a repository snapshot.