pub struct SoftwareGlobalStatus {Show 13 fields
pub repository_id: String,
pub source_scope: String,
pub projected_graph_version: GraphVersion,
pub stale: bool,
pub component_count: usize,
pub sdk_usage_count: usize,
pub file_count: usize,
pub topic_count: usize,
pub relationship_count: usize,
pub build_target_count: usize,
pub iac_resource_count: usize,
pub design_element_count: usize,
pub last_error: Option<String>,
}Expand description
Freshness and count summary for the software global projection.
Fields
repository_id: Stringsource_scope: Stringprojected_graph_version: GraphVersionstale: boolcomponent_count: usizesdk_usage_count: usizefile_count: usizetopic_count: usizerelationship_count: usizebuild_target_count: usizeiac_resource_count: usizedesign_element_count: usizelast_error: Option<String>Trait Implementations
Sourceimpl Clone for SoftwareGlobalStatus
impl Clone for SoftwareGlobalStatus
Sourcefn clone(&self) -> SoftwareGlobalStatus
fn clone(&self) -> SoftwareGlobalStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SoftwareGlobalStatus
impl Debug for SoftwareGlobalStatus
Sourceimpl<'de> Deserialize<'de> for SoftwareGlobalStatus
impl<'de> Deserialize<'de> for SoftwareGlobalStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SoftwareGlobalStatus
impl PartialEq for SoftwareGlobalStatus
Sourcefn eq(&self, other: &SoftwareGlobalStatus) -> bool
fn eq(&self, other: &SoftwareGlobalStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SoftwareGlobalStatus
impl Serialize for SoftwareGlobalStatus
impl Eq for SoftwareGlobalStatus
impl StructuralPartialEq for SoftwareGlobalStatus