pub struct SoftwareRelationship {Show 15 fields
pub relationship_id: String,
pub repository_id: String,
pub source_scope: String,
pub relationship_kind: String,
pub source_id: String,
pub source_kind: String,
pub target_id: String,
pub target_kind: String,
pub target_hint: Option<String>,
pub resolution_state: String,
pub confidence_basis_points: u16,
pub confidence_tier: String,
pub evidence_path: String,
pub evidence_line_range: RepositoryCodeRange,
pub created_graph_version: GraphVersion,
}Expand description
Cross-domain relationship between projected software files, topics, components, and usages.
Fields
relationship_id: Stringrepository_id: Stringsource_scope: Stringrelationship_kind: Stringsource_id: Stringsource_kind: Stringtarget_id: Stringtarget_kind: Stringtarget_hint: Option<String>resolution_state: Stringconfidence_basis_points: u16confidence_tier: Stringevidence_path: Stringevidence_line_range: RepositoryCodeRangecreated_graph_version: GraphVersionImplementations
Sourceimpl SoftwareRelationship
impl SoftwareRelationship
Sourcepub fn new(input: SoftwareRelationshipInput) -> Result<Self, DomainError>
pub fn new(input: SoftwareRelationshipInput) -> Result<Self, DomainError>
Creates a validated projected relationship without upgrading unresolved targets.