pub struct SoftwareTopic {
pub topic_id: String,
pub repository_id: String,
pub source_scope: String,
pub name: String,
pub topic_kind: String,
pub source_path: String,
pub line_range: RepositoryCodeRange,
pub created_graph_version: GraphVersion,
}Expand description
Topic extracted from repository documentation or the repository knowledge map.
Fields
topic_id: Stringrepository_id: Stringsource_scope: Stringname: Stringtopic_kind: Stringsource_path: Stringline_range: RepositoryCodeRangecreated_graph_version: GraphVersionImplementations
Sourceimpl SoftwareTopic
impl SoftwareTopic
Sourcepub fn new(input: SoftwareTopicInput) -> Result<Self, DomainError>
pub fn new(input: SoftwareTopicInput) -> Result<Self, DomainError>
Creates a stable topic identity tied to the source evidence location.