pub fn authorize_scope(
scope: Option<String>,
policy: &AgentAccessPolicy,
) -> Result<Option<String>, AgentAdapterError>Expand description
Validates and authorizes an optional source scope before service invocation.
pub fn authorize_scope(
scope: Option<String>,
policy: &AgentAccessPolicy,
) -> Result<Option<String>, AgentAdapterError>Validates and authorizes an optional source scope before service invocation.