pub async fn post_json(
config: &HttpConfig,
url: &str,
payload: &Value,
) -> Result<Value, HttpClientError>Expand description
Posts a JSON payload through the network boundary using the configured timeout.
pub async fn post_json(
config: &HttpConfig,
url: &str,
payload: &Value,
) -> Result<Value, HttpClientError>Posts a JSON payload through the network boundary using the configured timeout.