pub struct QosRuntime { /* private fields */ }Expand description
Runtime QoS counters used by inbound protocol adapters.
Implementations
Sourceimpl QosRuntime
impl QosRuntime
Sourcepub fn reserve_queue(
&self,
policy: &QosPolicy,
) -> Result<QosPermit, RejectReason>
pub fn reserve_queue( &self, policy: &QosPolicy, ) -> Result<QosPermit, RejectReason>
Reserves space in the bounded request queue before active admission.
Sourcepub fn admit_request(
&self,
policy: &QosPolicy,
) -> Result<QosPermit, RejectReason>
pub fn admit_request( &self, policy: &QosPolicy, ) -> Result<QosPermit, RejectReason>
Attempts to admit one inbound request and returns a release-on-drop permit.
Sourcepub fn admit_connection(
&self,
policy: &QosPolicy,
) -> Result<QosPermit, RejectReason>
pub fn admit_connection( &self, policy: &QosPolicy, ) -> Result<QosPermit, RejectReason>
Attempts to admit one open network connection.
Sourcepub fn snapshot(&self) -> QosSnapshot
pub fn snapshot(&self) -> QosSnapshot
Returns the current request budget snapshot for diagnostics and tests.