pub struct ReadModelBackendConfig {
pub semantic_mode: ReadModelBackendMode,
pub vector_mode: ReadModelBackendMode,
pub semantic_model: ReadModelMetadata,
pub vector_model: ReadModelMetadata,
pub image_model: ReadModelMetadata,
pub remote_embedding: Option<RemoteEmbeddingConfig>,
pub rerank: RerankConfig,
}Expand description
Runtime read model configuration shared by refresh and retrieval status.
Fields
semantic_mode: ReadModelBackendModevector_mode: ReadModelBackendModesemantic_model: ReadModelMetadatavector_model: ReadModelMetadataimage_model: ReadModelMetadataremote_embedding: Option<RemoteEmbeddingConfig>rerank: RerankConfigImplementations
Sourceimpl ReadModelBackendConfig
impl ReadModelBackendConfig
Sourcepub fn refreshes_index(&self, kind: IndexKind) -> bool
pub fn refreshes_index(&self, kind: IndexKind) -> bool
Returns whether local index refresh should maintain an index family.
Sourcepub fn disabled_retriever_sources(&self) -> Vec<RetrieverSource>
pub fn disabled_retriever_sources(&self) -> Vec<RetrieverSource>
Returns read-model retrievers that must not execute for a request.