pub struct CodeIndexTaskCompletion {
pub task_id: String,
pub lease_owner: String,
pub attempt_count: u32,
pub now_ms: u64,
}Expand description
Completion report guarded by task lease and attempt token.
Fields
task_id: Stringlease_owner: Stringattempt_count: u32now_ms: u64Trait Implementations
Sourceimpl Clone for CodeIndexTaskCompletion
impl Clone for CodeIndexTaskCompletion
Sourcefn clone(&self) -> CodeIndexTaskCompletion
fn clone(&self) -> CodeIndexTaskCompletion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeIndexTaskCompletion
impl Debug for CodeIndexTaskCompletion
Sourceimpl PartialEq for CodeIndexTaskCompletion
impl PartialEq for CodeIndexTaskCompletion
Sourcefn eq(&self, other: &CodeIndexTaskCompletion) -> bool
fn eq(&self, other: &CodeIndexTaskCompletion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CodeIndexTaskCompletion
impl StructuralPartialEq for CodeIndexTaskCompletion