pub struct CodeIndexTaskLeaseRenewal {
pub task_id: String,
pub lease_owner: String,
pub attempt_count: u32,
pub lease_duration_ms: u64,
pub now_ms: u64,
}Expand description
Lease renewal request for an actively running code index task.
Fields
task_id: Stringlease_owner: Stringattempt_count: u32lease_duration_ms: u64now_ms: u64Trait Implementations
Sourceimpl Clone for CodeIndexTaskLeaseRenewal
impl Clone for CodeIndexTaskLeaseRenewal
Sourcefn clone(&self) -> CodeIndexTaskLeaseRenewal
fn clone(&self) -> CodeIndexTaskLeaseRenewal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeIndexTaskLeaseRenewal
impl Debug for CodeIndexTaskLeaseRenewal
Sourceimpl PartialEq for CodeIndexTaskLeaseRenewal
impl PartialEq for CodeIndexTaskLeaseRenewal
Sourcefn eq(&self, other: &CodeIndexTaskLeaseRenewal) -> bool
fn eq(&self, other: &CodeIndexTaskLeaseRenewal) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CodeIndexTaskLeaseRenewal
impl StructuralPartialEq for CodeIndexTaskLeaseRenewal