pub struct FileIndexScanSummary {
pub root_count: usize,
pub indexed_file_count: usize,
pub missing_file_count: usize,
pub scan_error_count: usize,
pub truncated_root_count: usize,
pub roots: Vec<FileIndexRootStatus>,
}Expand description
Summary returned after one or more roots are indexed.
Fields
root_count: usizeindexed_file_count: usizemissing_file_count: usizescan_error_count: usizetruncated_root_count: usizeroots: Vec<FileIndexRootStatus>Trait Implementations
Sourceimpl Clone for FileIndexScanSummary
impl Clone for FileIndexScanSummary
Sourcefn clone(&self) -> FileIndexScanSummary
fn clone(&self) -> FileIndexScanSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileIndexScanSummary
impl Debug for FileIndexScanSummary
Sourceimpl Default for FileIndexScanSummary
impl Default for FileIndexScanSummary
Sourcefn default() -> FileIndexScanSummary
fn default() -> FileIndexScanSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FileIndexScanSummary
impl<'de> Deserialize<'de> for FileIndexScanSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FileIndexScanSummary
impl PartialEq for FileIndexScanSummary
Sourcefn eq(&self, other: &FileIndexScanSummary) -> bool
fn eq(&self, other: &FileIndexScanSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FileIndexScanSummary
impl Serialize for FileIndexScanSummary
impl Eq for FileIndexScanSummary
impl StructuralPartialEq for FileIndexScanSummary