pub struct GraphCanvasStorageEdge {
pub id: String,
pub kind: String,
pub source: String,
pub target: String,
pub label: String,
pub graph_version: GraphVersion,
pub confidence_basis_points: Option<u16>,
pub evidence_count: Option<usize>,
pub details: BTreeMap<String, String>,
}Expand description
Storage edge projected into the Web graph canvas contract.
Fields
id: Stringkind: Stringsource: Stringtarget: Stringlabel: Stringgraph_version: GraphVersionconfidence_basis_points: Option<u16>evidence_count: Option<usize>details: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for GraphCanvasStorageEdge
impl Clone for GraphCanvasStorageEdge
Sourcefn clone(&self) -> GraphCanvasStorageEdge
fn clone(&self) -> GraphCanvasStorageEdge
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphCanvasStorageEdge
impl Debug for GraphCanvasStorageEdge
Sourceimpl PartialEq for GraphCanvasStorageEdge
impl PartialEq for GraphCanvasStorageEdge
Sourcefn eq(&self, other: &GraphCanvasStorageEdge) -> bool
fn eq(&self, other: &GraphCanvasStorageEdge) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GraphCanvasStorageEdge
impl StructuralPartialEq for GraphCanvasStorageEdge