pub struct GraphCanvasStorageRequest {
pub selection: GraphCanvasSelection,
pub source_scope: Option<String>,
pub query: Option<String>,
pub graph_version: GraphVersion,
pub limit: usize,
}Expand description
Bounded graph canvas request against an explicit graph snapshot.
Fields
selection: GraphCanvasSelectionsource_scope: Option<String>query: Option<String>graph_version: GraphVersionlimit: usizeTrait Implementations
Sourceimpl Clone for GraphCanvasStorageRequest
impl Clone for GraphCanvasStorageRequest
Sourcefn clone(&self) -> GraphCanvasStorageRequest
fn clone(&self) -> GraphCanvasStorageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphCanvasStorageRequest
impl Debug for GraphCanvasStorageRequest
Sourceimpl PartialEq for GraphCanvasStorageRequest
impl PartialEq for GraphCanvasStorageRequest
Sourcefn eq(&self, other: &GraphCanvasStorageRequest) -> bool
fn eq(&self, other: &GraphCanvasStorageRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GraphCanvasStorageRequest
impl StructuralPartialEq for GraphCanvasStorageRequest