pub struct IndexRefreshCompletion {
pub task_id: String,
pub lease_owner: String,
pub attempt_count: u32,
pub indexed_graph_version: GraphVersion,
pub model_name: Option<String>,
pub model_dimension: Option<u32>,
pub now_ms: u64,
}Expand description
Completion report guarded by the active task lease and attempt token.
Fields
task_id: Stringlease_owner: Stringattempt_count: u32indexed_graph_version: GraphVersionmodel_name: Option<String>model_dimension: Option<u32>now_ms: u64Trait Implementations
Sourceimpl Clone for IndexRefreshCompletion
impl Clone for IndexRefreshCompletion
Sourcefn clone(&self) -> IndexRefreshCompletion
fn clone(&self) -> IndexRefreshCompletion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexRefreshCompletion
impl Debug for IndexRefreshCompletion
Sourceimpl PartialEq for IndexRefreshCompletion
impl PartialEq for IndexRefreshCompletion
Sourcefn eq(&self, other: &IndexRefreshCompletion) -> bool
fn eq(&self, other: &IndexRefreshCompletion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for IndexRefreshCompletion
impl StructuralPartialEq for IndexRefreshCompletion