pub struct IndexStalenessReason {
pub kind: IndexKind,
pub source_scope: Option<String>,
pub modality: Option<IndexModality>,
pub reason: String,
pub lag_versions: u64,
pub last_error: Option<String>,
}Expand description
Structured reason explaining why an index family or scoped cursor is stale.
Fields
kind: IndexKindsource_scope: Option<String>modality: Option<IndexModality>reason: Stringlag_versions: u64last_error: Option<String>Trait Implementations
Sourceimpl Clone for IndexStalenessReason
impl Clone for IndexStalenessReason
Sourcefn clone(&self) -> IndexStalenessReason
fn clone(&self) -> IndexStalenessReason
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexStalenessReason
impl Debug for IndexStalenessReason
Sourceimpl<'de> Deserialize<'de> for IndexStalenessReason
impl<'de> Deserialize<'de> for IndexStalenessReason
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for IndexStalenessReason
impl PartialEq for IndexStalenessReason
Sourcefn eq(&self, other: &IndexStalenessReason) -> bool
fn eq(&self, other: &IndexStalenessReason) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IndexStalenessReason
impl Serialize for IndexStalenessReason
impl Eq for IndexStalenessReason
impl StructuralPartialEq for IndexStalenessReason