CodeIndexPublicationStore

Trait CodeIndexPublicationStore 

pub trait CodeIndexPublicationStore: Send + Sync {
Show 16 methods // Required methods fn code_index_checkpoint( &self, source_scope: String, ) -> StorageFuture<'_, Option<CodeIndexCheckpoint>>; fn apply_code_index_snapshot( &self, snapshot: CodeIndexSnapshot, ) -> StorageFuture<'_, CodeIndexSummary>; // Provided methods fn latest_code_index_checkpoint( &self, repository_id: String, ) -> StorageFuture<'_, Option<CodeIndexCheckpoint>> { ... } fn apply_code_index_snapshot_with_fence( &self, snapshot: CodeIndexSnapshot, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexSummary> { ... } fn clear_code_workspace_state( &self, repository_id: String, source_scope: String, ) -> StorageFuture<'_, ()> { ... } fn code_repository_auto_workspace_state_exists( &self, repository_id: String, ) -> StorageFuture<'_, bool> { ... } fn clear_code_workspace_state_with_fence( &self, repository_id: String, source_scope: String, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, ()> { ... } fn begin_code_index_session( &self, session: CodeIndexSession, ) -> StorageFuture<'_, CodeIndexCheckpoint> { ... } fn begin_code_index_session_with_fence( &self, session: CodeIndexSession, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexCheckpoint> { ... } fn begin_code_index_session_at_checkpoint( &self, session: CodeIndexSession, expected_checkpoint: Option<CodeIndexCheckpoint>, ) -> StorageFuture<'_, CodeIndexCheckpoint> { ... } fn begin_code_index_session_at_checkpoint_with_fence( &self, session: CodeIndexSession, expected_checkpoint: Option<CodeIndexCheckpoint>, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexCheckpoint> { ... } fn apply_code_index_batch( &self, batch: CodeIndexBatch, ) -> StorageFuture<'_, CodeIndexCheckpoint> { ... } fn apply_code_index_batch_with_fence( &self, batch: CodeIndexBatch, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexCheckpoint> { ... } fn finalize_code_index_session( &self, session: CodeIndexSession, ) -> StorageFuture<'_, CodeIndexSummary> { ... } fn finalize_code_index_session_with_fence( &self, session: CodeIndexSession, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexSummary> { ... } fn advance_code_index_session_with_fence( &self, session: CodeIndexSession, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexFinalizationStep> { ... }
}
Checkpointed snapshot, batch, workspace, and final publication capability.

Required Methods

Provided Methods

fn latest_code_index_checkpoint( &self, repository_id: String, ) -> StorageFuture<'_, Option<CodeIndexCheckpoint>>

fn apply_code_index_snapshot_with_fence( &self, snapshot: CodeIndexSnapshot, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexSummary>

fn clear_code_workspace_state( &self, repository_id: String, source_scope: String, ) -> StorageFuture<'_, ()>

fn code_repository_auto_workspace_state_exists( &self, repository_id: String, ) -> StorageFuture<'_, bool>

Reports whether repository-owned auto-detected workspace artifacts still exist and therefore require a durable disabled-mode cleanup.

fn clear_code_workspace_state_with_fence( &self, repository_id: String, source_scope: String, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, ()>

fn begin_code_index_session( &self, session: CodeIndexSession, ) -> StorageFuture<'_, CodeIndexCheckpoint>

fn begin_code_index_session_with_fence( &self, session: CodeIndexSession, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexCheckpoint>

fn begin_code_index_session_at_checkpoint( &self, session: CodeIndexSession, expected_checkpoint: Option<CodeIndexCheckpoint>, ) -> StorageFuture<'_, CodeIndexCheckpoint>

Starts a checkpointed session only when the durable checkpoint still matches the value observed during read-only plan validation.

fn begin_code_index_session_at_checkpoint_with_fence( &self, session: CodeIndexSession, expected_checkpoint: Option<CodeIndexCheckpoint>, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexCheckpoint>

fn apply_code_index_batch( &self, batch: CodeIndexBatch, ) -> StorageFuture<'_, CodeIndexCheckpoint>

fn apply_code_index_batch_with_fence( &self, batch: CodeIndexBatch, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexCheckpoint>

fn finalize_code_index_session( &self, session: CodeIndexSession, ) -> StorageFuture<'_, CodeIndexSummary>

fn finalize_code_index_session_with_fence( &self, session: CodeIndexSession, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexSummary>

fn advance_code_index_session_with_fence( &self, session: CodeIndexSession, fence: CodeIndexPublicationFence, ) -> StorageFuture<'_, CodeIndexFinalizationStep>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors