Application services that orchestrate domain behavior behind stable API types.
Structs
- Agent
Durable Audit Input - Durable audit event input accepted from resident agent adapters.
- Agent
Runtime Config - Resident agent protocol runtime configuration.
- File
Index Root Config - One authorized local file index root.
- File
Index Runtime Config - Runtime budgets and authorized roots for local file-location indexing.
- Relay
Knowledge Service - Shared application service used by CLI, Web, and future API adapters.
- Runtime
Configuration - Resolved foundation configuration shared by all interfaces.
- Worker
Runtime Config - External worker runtime configuration and deterministic fallback policy.
Enums
- Retrieval
Runtime Config Error - Retrieval runtime configuration validation error.
- Runtime
Configuration Error - Error raised while composing foundational runtime configuration.