pub struct GraphSearchRequest {
pub query: String,
pub source_scope: Option<String>,
pub graph_version: GraphVersion,
pub limit: usize,
pub disabled_retriever_sources: Vec<RetrieverSource>,
}Expand description
Bounded graph search request against an explicit graph snapshot.
Fields
query: Stringsource_scope: Option<String>graph_version: GraphVersionlimit: usizedisabled_retriever_sources: Vec<RetrieverSource>Implementations
Sourceimpl GraphSearchRequest
impl GraphSearchRequest
Sourcepub fn allows_retriever_source(&self, source: RetrieverSource) -> bool
pub fn allows_retriever_source(&self, source: RetrieverSource) -> bool
Returns whether storage may execute a retriever family for this request.