pub trait CodeRepositoryStore:
FrameworkGraphStore
+ RepositoryCatalogStore
+ CodeIndexTaskStore
+ CodeScopeRetentionStore
+ CodeIndexSourceStore
+ CodeIndexPublicationStore
+ CodeQueryReadStore
+ SoftwareProjectionStore
+ CodeRepositorySetStore { }Expand description
Compatibility facade that combines all persisted code repository capabilities. New workflows depend on the narrow capability they consume.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".